@@ -3,13 +3,13 @@ package Quiq;
 use strict;
 use warnings;
 
-our $VERSION = '1.162';
+our $VERSION = '1.163';
 
 =encoding utf8
 
 =head1 NAME
 
-Quiq - Class library for rapid development (Documentation in German)
+Quiq - Class library for rapid development (German documentation)
 
 =head1 DESCRIPTION
 
@@ -36,7 +36,7 @@ L<Quiq::Array> - Operationen auf Arrays
 
 =item *
 
-L<Quiq::AsciiTable> - ASCII-Tabelle parsen
+L<Quiq::AsciiTable> - Parse ASCII-Tabelle
 
 =item *
 
@@ -44,6 +44,18 @@ L<Quiq::Assert> - Zusicherungen
 
 =item *
 
+L<Quiq::Axis> - Definition einer Plot-Achse (abstrakte Basisklasse)
+
+=item *
+
+L<Quiq::Axis::Numeric> - Definition einer numerischen Plot-Achse
+
+=item *
+
+L<Quiq::AxisTick> - Tick einer Plot-Achse
+
+=item *
+
 L<Quiq::Cascm> - Schnittstelle zu CA Harvest SCM
 
 =item *
@@ -248,6 +260,34 @@ L<Quiq::Gd::Font> - GD- oder TrueType-Font
 
 =item *
 
+L<Quiq::Gd::Graphic> - Basisklasse aller Graphic-Klassen (abstrakt)
+
+=item *
+
+L<Quiq::Gd::Graphic::Axis> - Grafik einer Achse eines XY-Plot
+
+=item *
+
+L<Quiq::Gd::Graphic::BlockDiagram> - Farbige Blöcke in einer Fläche
+
+=item *
+
+L<Quiq::Gd::Graphic::ColorBar> - Rechteck mit einem Farbverlauf
+
+=item *
+
+L<Quiq::Gd::Graphic::ColorLegend> - Legende zu einem Farb-Plot
+
+=item *
+
+L<Quiq::Gd::Graphic::Graph> - Polyline-Grafik für XY-Plot
+
+=item *
+
+L<Quiq::Gd::Graphic::PointGraph> - Polyline-Grafik für XY-Plot mit farbigen Punkten
+
+=item *
+
 L<Quiq::Gd::Image> - Schnittstelle zur GD Graphics Library
 
 =item *
@@ -560,10 +600,6 @@ L<Quiq::Process> - Information über den laufenden Prozess
 
 =item *
 
-L<Quiq::ProcessMatrix> - Matrix von zeitlichen Vorgängen
-
-=item *
-
 L<Quiq::Program> - Basisklasse für Programme
 
 =item *
@@ -592,6 +628,10 @@ L<Quiq::Rsync> - Aufruf von rsync von Perl aus
 
 =item *
 
+L<Quiq::Schedule> - Matrix von zeitlichen Vorgängen
+
+=item *
+
 L<Quiq::Sdoc::Producer> - Sdoc-Generator
 
 =item *
@@ -758,7 +798,7 @@ L<Quiq::Xml::LibXml> - Funktionale Erweiterungen von XML::LibXML
 
 =head1 VERSION
 
-1.162
+1.163
 
 =head1 AUTHOR
 
