@@ -5,7 +5,7 @@ use v5.10;
 use strict;
 use warnings;
 
-our $VERSION = '1.162';
+our $VERSION = '1.163';
 
 use Quiq::Unindent;
 
@@ -15,7 +15,7 @@ use Quiq::Unindent;
 
 =head1 NAME
 
-Quiq::AsciiTable - ASCII-Tabelle parsen
+Quiq::AsciiTable - Parse ASCII-Tabelle
 
 =head1 BASE CLASS
 
@@ -612,7 +612,7 @@ sub asText {
 
 =head1 VERSION
 
-1.162
+1.163
 
 =head1 AUTHOR
 
